'Writing PICAXE BASIC Code
'PICAXE Tutorial
'Experiment: Controlling 28BYJ-48 Unipolar Stepper with Infrared
'8 Jan 2017
'Schematic: PA14M2 IR Tracking Controller
'Code: PA14M2 IR Tracking Controller.bas
'Overview: 'Drive 28BYJ-48 stepper motor as controlled by 3 IR
	'phototransistors responding to the position of an IR LED.
#picaxe 14M2 'Identify the PICAXE being used as an 14M2.
#no_data 'Prevent data from being downloaded to PICAXE.
	symbol step_delay = 1 'Pause duration (must be at least 1 ms.)
	symbol rit_IR_in = C.4 'Assign rit_IR_in to represent pinC.4.
	symbol ctr_IR_in = C.0 'Assign ctr_IR_in to represent pinC.0.
	symbol lft_IR_in = B.5 'Assign lft_IR_in to represent pinB.5.
	symbol rit_val = b4 'Define variable b4 to store the digital value of
				'the right IR voltage reading.
	symbol ctr_val = b5 'Define variable b5 to store the digital value of
				'the center IR voltage reading.
	symbol lft_val = b6 'Define variable b6 to store the digital value of
				'the left IR voltage reading.	
init: 'Initialize the PICAXE.
let dirsB = %00011110	'Set pins B.4, B.3, B.2, and B.1 as outputs.
main:
readadc rit_IR_in, rit_val 'Read right IR analog value, convert it
	'to digital, and store it in rit_val.
	readadc ctr_IR_in, ctr_val 'Read center IR analog value, convert it
	'to digital, and store it in ctr_val.
	readadc lft_IR_in, lft_val 'Read left IR analog value, convert it
	'to digital, and store it in lft_val.
if ctr_val => lft_val and ctr_val => rit_val then
	goto main 'Do nothing except loop as long as ctr_val is highest value.
elseif lft_val > rit_val and lft_val > ctr_val then
	goto rit_to_lft
elseif rit_val > lft_val and rit_val > ctr_val then
	goto lft_to_rit
endif
goto main
lft_to_rit: 'Turn stepper left to right four steps.
	let pinsB = %00110 'blu (A, B.1) and pnk (B, B.2) windings high.
		pause step_delay
	let pinsB = %01100 'pnk (B, B.2) and yel (C, B.3) windings high.
		pause step_delay
	let pinsB = %11000 'yel (C, B.3) and orn (D, B.4) windings high.
		pause step_delay
	let pinsB = %10010 'orn (D, B.4) and blu (A, B.1) windings high.
		pause step_delay
	let pinsB = %00000 'Turn off all stepper windings.
goto main 'Loop back to main, and repeat program.
rit_to_lft: 'Turn stepper right to left four steps.
	let pinsB = %10010 'orn (D, B.4) and blu (A, B.1) windings high.
		pause step_delay
	let pinsB = %11000 'yel (C, B.3) and orn (D, B.4) windings high.
		pause step_delay
	let pinsB = %01100 'pnk (B, B.2) and yel (C, B.3) windings high.
		pause step_delay
	let pinsB = %00110 'blu (A, B.1) and pnk (B, B.2) windings high.
		pause step_delay
	let pinsB = %00000 'Turn off all stepper windings.
goto main 'Loop back to main, and repeat program.